@@ -16,15 +16,24 @@ class ProcessRunner(BaseRunner):
     _child_process = 0
 
     def perform_tasks(self, tasks):
+        messages = []
         for message, task in tasks:
-            self.perform_task(task)
+            self.perform_task(task, False)
+            messages.append(message)
 
-    def perform_task(self, task):
+        self.finished_tasks(messages)
+
+    def perform_task(self, task, delete_message=True):
         child_pid = os.fork()
         if child_pid == 0:
-            result = task.run()
+            try:
+                result = task.run()
+            except Exception, e:
+                result = e
+
             logger.info("Result %s" % result)
-            os._exit(int(not result))
+            if delete_message:
+                self.finished_task(task[0])
 
         else:
             logger.info("Started forked worker")
